@@ -1,7 +1,7 @@
 static const char *petscmachineinfo = "\n"
 "-----------------------------------------\n"
-"Libraries compiled on 2025-10-29 18:37:20 on reproducible\n"
-"Machine characteristics: Linux-6.17.4-arch2-1-x86_64-with-glibc2.42\n"
+"Libraries compiled on 2025-12-17 05:37:41 on reproducible\n"
+"Machine characteristics: Linux-6.17.9-arch1-1-x86_64-with-glibc2.42\n"
 "Using PETSc directory: /opt/petsc/linux-c-opt\n"
 "Using PETSc arch: \n"
 "-----------------------------------------\n";
@@ -15,5 +15,5 @@ static const char *petsccompilerflagsinfo = "\n"
 static const char *petsclinkerinfo = "\n"
 "Using C linker: /usr/bin/mpicc\n"
 "Using Fortran linker: /usr/bin/mpif90\n"
-"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lpastix -lsuperlu -lkokkoscore -llapack -lblas -lzfp -lzoltan -lesmumps -lptscotch -lptscotcherr -lscotch -lscotcherr -lbz2 -lnetcdf -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -ltriangle -lgsl -lgslcblas -lm -lz -ljpeg -lyaml -lhwloc -lX11 -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
+"Using libraries: -Wl,-rpath,/opt/petsc/linux-c-opt/lib -L/opt/petsc/linux-c-opt/lib -lpetsc -Wl,-rpath,/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 -L/usr/lib/gcc/x86_64-pc-linux-gnu/15.2.1 /usr/lib/libHYPRE.so -lspqr -lumfpack -lklu -lcholmod -lamd -lfftw3_mpi -lfftw3 -ldmumps -lmumps_common -lpord -lpthread -lscalapack -lsuperlu_dist -lpastix -lsuperlu -lkokkoscore -llapack -lblas -lzfp -lzoltan -lesmumps -lptscotch -lptscotcherr -lscotch -lscotcherr -lhdf5_hl_fortran -lhdf5_fortran -lhdf5_hl_f90cstub -lhdf5_f90cstub -lhdf5_hl -lhdf5 -lparmetis -lmetis -ltriangle -lgsl -lgslcblas -lm -ljpeg -lyaml -lhwloc -lX11 -lmpi_usempif08 -lmpi_usempi_ignore_tkr -lmpi_mpifh -lmpi -lgfortran -lm -lgfortran -lm -lgcc_s -lquadmath\n"
 "-----------------------------------------\n";
